==> core-1.3.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/IResolveContext.java <==
package software.amazon.awscdk.core;

/**
 * Current resolution context for tokens.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-02T10:04:40.280Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IResolveContext extends software.amazon.jsii.JsiiSerializable {
    /**
     * The scope from which resolution has been initiated.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IConstruct getScope();
    /**
     * Use this postprocessor after the entire token structure has been resolved.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    void registerPostProcessor(final software.amazon.awscdk.core.IPostProcessor postProcessor);
    /**
     * Resolve an inner object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Object resolve(@javax.annotation.Nullable final java.lang.Object x);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.IResolveContext {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The scope from which resolution has been initiated.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.IConstruct getScope() {
            return this.jsiiGet("scope", software.amazon.awscdk.core.IConstruct.class);
        }

        /**
         * Use this postprocessor after the entire token structure has been resolved.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public void registerPostProcessor(final software.amazon.awscdk.core.IPostProcessor postProcessor) {
            this.jsiiCall("registerPostProcessor", Void.class, new Object[] { java.util.Objects.requireNonNull(postProcessor, "postProcessor is required") });
        }

        /**
         * Resolve an inner object.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        @javax.annotation.Nullable
        public java.lang.Object resolve(@javax.annotation.Nullable final java.lang.Object x) {
            return this.jsiiCall("resolve", java.lang.Object.class, new Object[] { x });
        }
    }
}

==> core-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/IResolveContext.java <==
package software.amazon.awscdk.core;

/**
 * Current resolution context for tokens.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:10:20.285Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IResolveContext extends software.amazon.jsii.JsiiSerializable {
    /**
     * True when we are still preparing, false if we're rendering the final output.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Boolean getPreparing();
    /**
     * The scope from which resolution has been initiated.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IConstruct getScope();
    /**
     * Use this postprocessor after the entire token structure has been resolved.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    void registerPostProcessor(final software.amazon.awscdk.core.IPostProcessor postProcessor);
    /**
     * Resolve an inner object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Object resolve(@javax.annotation.Nullable final java.lang.Object x);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.core.IResolveContext {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * True when we are still preparing, false if we're rendering the final output.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.Boolean getPreparing() {
            return this.jsiiGet("preparing", java.lang.Boolean.class);
        }

        /**
         * The scope from which resolution has been initiated.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.IConstruct getScope() {
            return this.jsiiGet("scope", software.amazon.awscdk.core.IConstruct.class);
        }

        /**
         * Use this postprocessor after the entire token structure has been resolved.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public void registerPostProcessor(final software.amazon.awscdk.core.IPostProcessor postProcessor) {
            this.jsiiCall("registerPostProcessor", Void.class, new Object[] { java.util.Objects.requireNonNull(postProcessor, "postProcessor is required") });
        }

        /**
         * Resolve an inner object.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        @javax.annotation.Nullable
        public java.lang.Object resolve(@javax.annotation.Nullable final java.lang.Object x) {
            return this.jsiiCall("resolve", java.lang.Object.class, new Object[] { x });
        }
    }
}
